@@ -1,7 +1,6 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import datetime
 from tornado.gen import coroutine
 
 from holmes.utils import get_status_code_title
@@ -63,23 +62,16 @@ class RequestDomainHandler(BaseHandler):
 class LastRequestsHandler(BaseHandler):
     @coroutine
     def get(self):
-        current_page = int(self.get_argument('current_page', 1))
-        page_size = int(self.get_argument('page_size', 10))
-
         requests = Request.get_last_requests(
             self.db,
-            current_page=current_page,
-            page_size=page_size
+            current_page=int(self.get_argument('current_page', 1)),
+            page_size=int(self.get_argument('page_size', 10)),
+            domain_filter=self.get_argument('domain_filter', None)
         )
 
-        requests_count = yield self.cache.get_requests_count()
-
-        result = {'requestsCount': requests_count, 'requests': []}
-
-        for request in requests:
-            result['requests'].append(request.to_dict())
-
-        self.write_json(result)
+        self.write_json(
+            {'requests': [request.to_dict() for request in requests]}
+        )
 
 
 class RequestsInLastDayHandler(BaseHandler):
@@ -91,7 +83,7 @@ class RequestsInLastDayHandler(BaseHandler):
         for status_code, count in requests:
             result.append({
                 'statusCode': status_code,
-                'statusCodeTitle': get_status_code_title(status_code),  # FIXME: is it code or title??
+                'statusCodeTitle': get_status_code_title(status_code),
                 'count': count,
             })
 
