@@ -45,7 +45,9 @@ class ReviewHandler(BaseReviewHandler):
 
 class LastReviewsHandler(BaseReviewHandler):
     def get(self):
-        reviews = Review.get_last_reviews(self.db)
+        reviews = Review.get_last_reviews(
+            self.db, domain_filter=self.get_argument('domain_filter', None)
+        )
 
         reviews_json = []
         for review in reviews:
@@ -64,7 +66,8 @@ class ReviewsInLastHourHandler(BaseReviewHandler):
         from_date = datetime.datetime.utcnow() - datetime.timedelta(hours=1)
         count, first_date = Review.get_reviews_count_in_period(
             self.db,
-            from_date=from_date
+            from_date=from_date,
+            domain_filter=self.get_argument('domain_filter', None)
         )
 
         if first_date:
