@@ -1,9 +1,6 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-import sys
-import logging
-
 from uuid import uuid4
 from datetime import datetime
 
@@ -82,21 +79,35 @@ class Review(Base):
         return self.failure_message is not None
 
     @classmethod
-    def get_last_reviews(cls, db, limit=12):
-        return db.query(Review).filter(Review.is_active == True) \
-                               .order_by(Review.completed_date.desc())[:limit]
+    def get_last_reviews(cls, db, domain_filter=None, limit=12):
+        query = db.query(Review).filter(Review.is_active == True)
+
+        if domain_filter:
+            from holmes.models.domain import Domain
+            domain = Domain.get_domain_by_name(domain_filter, db)
+            if domain:
+                query = query.filter(Review.domain_id == domain.id)
+
+        return query.order_by(Review.completed_date.desc())[:limit]
 
     @classmethod
-    def get_reviews_count_in_period(cls, db, from_date, to_date=None):
+    def get_reviews_count_in_period(cls, db, from_date, domain_filter=None,
+                                    to_date=None):
         if to_date is None:
             to_date = datetime.utcnow()
 
         reviews = db \
             .query(Review.completed_date) \
             .filter(Review.is_active == True) \
-            .filter(Review.completed_date.between(from_date, to_date)) \
-            .order_by(Review.completed_date.asc()) \
-            .all()
+            .filter(Review.completed_date.between(from_date, to_date))
+
+        if domain_filter:
+            from holmes.models.domain import Domain
+            domain = Domain.get_domain_by_name(domain_filter, db)
+            if domain:
+                reviews = reviews.filter(Review.domain_id == domain.id)
+
+        reviews = reviews.order_by(Review.completed_date.asc()).all()
 
         count = len(reviews)
 
@@ -266,23 +277,7 @@ class Review(Base):
 
         if not last_review:
             cache.increment_active_review_count(page.domain)
-
-            cache.increment_violations_count(
-                page.domain,
-                increment=page.violations_count
-            )
-
-            cache.increment_next_jobs_count(-1)
-
         else:
-            old_violations_count = len(last_review.violations)
-            new_violations_count = len(review.violations)
-
-            cache.increment_violations_count(
-                page.domain,
-                increment=new_violations_count - old_violations_count
-            )
-
             for violation in last_review.violations:
                 violation.review_is_active = False
 
